@@ -161,8 +161,9 @@ class Kadence_Blocks_Advancedheading_Block extends Kadence_Blocks_Abstract_Block
 		if( !empty( $attributes['textGradient'] ) && ! empty( $attributes['enableTextGradient'] ) ) {
 			$css->set_selector( '.wp-block-kadence-advancedheading.kt-adv-heading' . $unique_id . ', .wp-block-kadence-advancedheading.kt-adv-heading' . $unique_id . '[data-kb-block="kb-adv-heading' . $unique_id . '"] .kb-adv-text-inner' );
 			$css->add_property( 'background-image', $attributes['textGradient'] );
-			$css->add_property( '-webkit-box-decoration-break', 'clone' );
 			$css->add_property( 'background-clip', 'text' );
+			$css->add_property( '-webkit-box-decoration-break', 'clone' );
+			$css->add_property( 'box-decoration-break', 'clone' );
 			$css->add_property( '-webkit-background-clip', 'text' );
 			$css->add_property( '-webkit-text-fill-color', 'transparent' );
 			$css->set_selector( '.wp-block-kadence-advancedheading.kt-adv-heading' . $unique_id . ', .wp-block-kadence-advancedheading.kt-adv-heading' . $unique_id . '[data-kb-block="kb-adv-heading' . $unique_id . '"]' );
@@ -304,15 +305,17 @@ class Kadence_Blocks_Advancedheading_Block extends Kadence_Blocks_Abstract_Block
 			$css->add_property( 'color', $css->render_color( $attributes['markColor'] ) );
 		} else if ( !empty( $attributes['markGradient'] ) && ! empty( $attributes['enableMarkGradient'] ) ) {
 			$css->add_property( 'background-image', $attributes['markGradient'] );
-			$css->add_property( '-webkit-box-decoration-break', 'clone' );
 			$css->add_property( '-webkit-background-clip', 'text' );
 			$css->add_property( 'background-clip', 'text' );
 			$css->add_property( '-webkit-text-fill-color', 'transparent' );
 		}
+		if ( ! empty($attributes['enableMarkBackgroundGradient']) && ! empty($attributes['markBackgroundGradient']) ) {
+			$css->add_property( 'background-image', $attributes['markBackgroundGradient'] );
+		}
 		if ( ! empty( $attributes['markTextTransform'] ) ) {
 			$css->add_property( 'text-transform', $attributes['markTextTransform'] );
 		}
-		if ( ! empty( $attributes['markBG'] ) && empty( $attributes['enableMarkGradient'] ) ) {
+		if ( ! empty( $attributes['markBG'] ) && empty( $attributes['enableMarkGradient'] ) && empty( $attributes['enableMarkBackgroundGradient'] ) ) {
 			$alpha = ( isset( $attributes['markBGOpacity'] ) && ! empty( $attributes['markBGOpacity'] ) ? $attributes['markBGOpacity'] : 1 );
 			$css->add_property( 'background', $css->render_color( $attributes['markBG'], $alpha ) );
 		}
@@ -328,7 +331,8 @@ class Kadence_Blocks_Advancedheading_Block extends Kadence_Blocks_Abstract_Block
 		}
 		$css->render_border_styles( $attributes, 'markBorderStyles' );
 		$css->render_border_radius( $attributes, 'markBorderRadius', ( ! empty( $attributes['markBorderRadiusUnit'] ) ? $attributes['markBorderRadiusUnit'] : 'px' ) );
-
+		$css->add_property( '-webkit-box-decoration-break', 'clone' );
+		$css->add_property( 'box-decoration-break', 'clone' );
 		$css->set_media_state( 'tablet' );
 		$css->render_border_radius( $attributes, 'tabletMarkBorderRadius', ( ! empty( $attributes['markBorderRadiusUnit'] ) ? $attributes['markBorderRadiusUnit'] : 'px' ) );
 		$css->set_media_state( 'desktop' );
